@@ -1,4 +1,4 @@
-from lucas_helpers_webforce.database import *
+from lucas_helpers_webforce import mysql
 from lucas_helpers_webforce import events
 from lucas_helpers_webforce import libraries
 from lucas_helpers_webforce import models
